@@ -274,12 +274,12 @@ static char *format_timestamp_internal(
         assert(buf);
 
         if (l <
-            3 +                  /* week day */
+            (size_t)(3 +         /* week day */
             1 + 10 +             /* space and date */
             1 + 8 +              /* space and time */
             (us ? 1 + 6 : 0) +   /* "." and microsecond part */
             1 + 1 +              /* space and shortest possible zone */
-            1)
+            1) )
                 return NULL; /* Not enough space even for the shortest form. */
         if (t <= 0 || t == USEC_INFINITY)
                 return NULL; /* Timestamp is unset */
@@ -540,9 +540,6 @@ char *format_timespan(char *buf, size_t l, usec_t t, usec_t accuracy) {
         return buf;
 }
 
-#if 0 /// UNNEEDED by elogind
-#endif // 0
-
 #if 0 /// UNNEEDED by elogind
 static int parse_timestamp_impl(const char *t, usec_t *usec, bool with_tz) {
         static const struct {
