@@ -418,6 +418,10 @@ int elogind_manager_new(Manager* m) {
         m->hybrid_sleep_mode   = NULL;
         m->hybrid_sleep_state  = NULL;
         m->hibernate_delay_sec = 0;
+        m->allow_suspend       = -1;
+        m->allow_hibernation   = -1;
+        m->allow_hybrid_sleep  = -1;
+        m->allow_suspend_then_hibernate = -1;
 
         /* If elogind should be its own controller, mount its cgroup */
         if (streq(SYSTEMD_CGROUP_CONTROLLER, "_elogind")) {
@@ -434,58 +438,6 @@ int elogind_manager_new(Manager* m) {
 }
 
 
-/// Add-On for manager_reset_config()
-void elogind_manager_reset_config(Manager* m) {
-
-#if ENABLE_DEBUG_ELOGIND
-        int dbg_cnt;
-#endif // ENABLE_DEBUG_ELOGIND
-
-        /* Set default Sleep config if not already set by logind.conf */
-        if (!m->suspend_state)
-                m->suspend_state = strv_new("mem", "standby", "freeze", NULL);
-        if (!m->hibernate_mode)
-                m->hibernate_mode = strv_new("platform", "shutdown", NULL);
-        if (!m->hibernate_state)
-                m->hibernate_state = strv_new("disk", NULL);
-        if (!m->hybrid_sleep_mode)
-                m->hybrid_sleep_mode = strv_new("suspend", "platform", "shutdown", NULL);
-        if (!m->hybrid_sleep_state)
-                m->hybrid_sleep_state = strv_new("disk", NULL);
-        if (!m->hibernate_delay_sec)
-                m->hibernate_delay_sec = 180 * USEC_PER_MINUTE;
-
-#if ENABLE_DEBUG_ELOGIND
-        dbg_cnt = -1;
-        while (m->suspend_mode && m->suspend_mode[++dbg_cnt])
-                log_debug_elogind("suspend_mode[%d] = %s",
-                                  dbg_cnt, m->suspend_mode[dbg_cnt]);
-        dbg_cnt = -1;
-        while (m->suspend_state[++dbg_cnt])
-                log_debug_elogind("suspend_state[%d] = %s",
-                                  dbg_cnt, m->suspend_state[dbg_cnt]);
-        dbg_cnt = -1;
-        while (m->hibernate_mode[++dbg_cnt])
-                log_debug_elogind("hibernate_mode[%d] = %s",
-                                  dbg_cnt, m->hibernate_mode[dbg_cnt]);
-        dbg_cnt = -1;
-        while (m->hibernate_state[++dbg_cnt])
-                log_debug_elogind("hibernate_state[%d] = %s",
-                                  dbg_cnt, m->hibernate_state[dbg_cnt]);
-        dbg_cnt = -1;
-        while (m->hybrid_sleep_mode[++dbg_cnt])
-                log_debug_elogind("hybrid_sleep_mode[%d] = %s",
-                                  dbg_cnt, m->hybrid_sleep_mode[dbg_cnt]);
-        dbg_cnt = -1;
-        while (m->hybrid_sleep_state[++dbg_cnt])
-                log_debug_elogind("hybrid_sleep_state[%d] = %s",
-                                  dbg_cnt, m->hybrid_sleep_state[dbg_cnt]);
-        log_debug_elogind("hibernate_delay_sec: %lu seconds (%lu minutes)",
-                          m->hibernate_delay_sec / USEC_PER_SEC,
-                          m->hibernate_delay_sec / USEC_PER_MINUTE);
-#endif // ENABLE_DEBUG_ELOGIND
-}
-
 /// Add-On for manager_startup()
 int elogind_manager_startup(Manager* m) {
         int r, e = 0;
