@@ -58,7 +58,7 @@ struct Session {
         Manager *manager;
 
         const char *id;
-        unsigned int position;
+        unsigned position;
         SessionType type;
         SessionClass class;
 
@@ -84,7 +84,7 @@ struct Session {
 #endif // 0
 
         Seat *seat;
-        unsigned int vtnr;
+        unsigned vtnr;
         int vtfd;
 
         pid_t leader;
@@ -175,7 +175,6 @@ const char* tty_validity_to_string(TTYValidity t) _const_;
 TTYValidity tty_validity_from_string(const char *s) _pure_;
 
 int session_prepare_vt(Session *s);
-void session_restore_vt(Session *s);
 void session_leave_vt(Session *s);
 
 bool session_is_controller(Session *s, const char *sender);
