@@ -11,6 +11,7 @@
 //#include "bus-util.h"
 //#include "cgroup-util.h"
 #include "clean-ipc.h"
+#include "env-file.h"
 #include "escape.h"
 #include "fd-util.h"
 #include "fileio.h"
@@ -23,10 +24,12 @@
 //#include "parse-util.h"
 //#include "path-util.h"
 //#include "rm-rf.h"
+#include "serialize.h"
 #include "special.h"
 #include "stdio-util.h"
 #include "string-table.h"
 #include "strv.h"
+#include "tmpfile-util.h"
 #include "unit-name.h"
 #include "user-util.h"
 //#include "util.h"
@@ -113,7 +116,6 @@ User *user_free(User *u) {
                 return NULL;
 
         log_debug_elogind("Freeing User %s ...", u->name);
-
         if (u->in_gc_queue)
                 LIST_REMOVE(gc_queue, u->manager->user_gc_queue, u);
 
@@ -323,15 +325,14 @@ int user_load(User *u) {
 
         assert(u);
 
-        r = parse_env_file(NULL, u->state_file, NEWLINE,
-#if 0 /// elogind neither supports service nor slice jobs
+        r = parse_env_file(NULL, u->state_file,
+#if 0 /// elogind neither supports service jobs
                            "SERVICE_JOB",            &u->service_job,
 #endif // 0
                            "STOPPING",               &stopping,
                            "REALTIME",               &realtime,
                            "MONOTONIC",              &monotonic,
-                           "LAST_SESSION_TIMESTAMP", &last_session_timestamp,
-                           NULL);
+                           "LAST_SESSION_TIMESTAMP", &last_session_timestamp);
         if (r == -ENOENT)
                 return 0;
         if (r < 0)
@@ -343,44 +344,23 @@ int user_load(User *u) {
                         log_debug_errno(r, "Failed to parse 'STOPPING' boolean: %s", stopping);
                 else
                         u->stopping = r;
-                log_debug_elogind(" --> User stopping    : %d", u->stopping);
         }
 
         if (realtime)
-                (void) timestamp_deserialize(realtime, &u->timestamp.realtime);
+                (void) deserialize_usec(realtime, &u->timestamp.realtime);
         if (monotonic)
-                (void) timestamp_deserialize(monotonic, &u->timestamp.monotonic);
+                (void) deserialize_usec(monotonic, &u->timestamp.monotonic);
         if (last_session_timestamp)
-                (void) timestamp_deserialize(last_session_timestamp, &u->last_session_timestamp);
+                (void) deserialize_usec(last_session_timestamp, &u->last_session_timestamp);
 
+        log_debug_elogind(" --> User stopping    : %d",  u->stopping);
         log_debug_elogind(" --> User realtime    : %lu", u->timestamp.realtime);
         log_debug_elogind(" --> User monotonic   : %lu", u->timestamp.monotonic);
         log_debug_elogind(" --> User last session: %lu", u->last_session_timestamp);
-#if ENABLE_DEBUG_ELOGIND
-        _cleanup_strv_free_ char **sa = NULL;
-        _cleanup_free_ char *sv = NULL;
-        Session *i;
-        bool first;
-
-        first = true;
-        LIST_FOREACH(sessions_by_user, i, u->sessions) {
-                if (first)
-                        first = false;
-                else
-                        strv_extend(&sa, " ");
-                strv_extend(&sa, i->id);
-        }
-
-        if (false == first) {
-                sv = strv_join(sa, " ");
-        }
-#endif // ENABLE_DEBUG_ELOGIND
-        log_debug_elogind(" --> User sessions    : %s",  u->sessions ? sv : "none");
-
         return 0;
 }
 
-#if 0 /// elogind neither spawns systemd --user nor suports systemd units and services.
+#if 0 /// elogind neither spawns systemd --user nor supports systemd units and services.
 static void user_start_service(User *u) {
         _cleanup_(sd_bus_error_free) sd_bus_error error = SD_BUS_ERROR_NULL;
         int r;
@@ -420,8 +400,8 @@ int user_start(User *u) {
         if (r < 0)
                 return r;
 #endif // 1
-        /* Save the user data so far, because pam_systemd will read the XDG_RUNTIME_DIR out of it while starting up
-         * systemd --user.  We need to do user_save_internal() because we have not "officially" started yet. */
+        /* Save the user data so far, because pam_elogind will read the XDG_RUNTIME_DIR out of it while starting up
+         * elogind --user.  We need to do user_save_internal() because we have not "officially" started yet. */
         user_save_internal(u);
 
 #if 0 /// elogind does not spawn user instances of systemd
@@ -480,7 +460,6 @@ int user_stop(User *u, bool force) {
         }
 
         log_debug_elogind("Stopping user %s %s ...", u->name, force ? "(forced)" : "");
-
         LIST_FOREACH(sessions_by_user, s, u->sessions) {
                 int k;
 
@@ -513,7 +492,6 @@ int user_finalize(User *u) {
 
         if (u->started)
                 log_debug("User %s logged out.", u->name);
-        else
                 log_debug_elogind("User %s not started, finalizing...", u->name);
 
         LIST_FOREACH(sessions_by_user, s, u->sessions) {
@@ -606,7 +584,7 @@ int user_check_linger_file(User *u) {
         return true;
 }
 
-#if 0 /// elogind does not support systemd units
+#if 0 /// UNNEEDED by elogind
 static bool user_unit_active(User *u) {
         const char *i;
         int r;
@@ -641,7 +619,6 @@ bool user_may_gc(User *u, bool drop_not_started) {
         log_debug_elogind("  is sessionless : %s", yes_no(!u->sessions));
         log_debug_elogind("  not lingering  : %s", yes_no(user_check_linger_file(u) > 0));
         log_debug_elogind("  dns or stopping: %s", yes_no(drop_not_started || u->stopping));
-
         if (drop_not_started && !u->started)
                 return true;
 
@@ -914,17 +891,19 @@ int config_parse_tmpfs_size(
         assert(data);
 
         /* First, try to parse as percentage */
-        r = parse_percent(rvalue);
-        if (r > 0 && r < 100)
-                *sz = physical_memory_scale(r, 100U);
+        r = parse_permille(rvalue);
+        if (r > 0 && r < 1000)
+                *sz = physical_memory_scale(r, 1000U);
         else {
                 uint64_t k;
 
                 /* If the passed argument was not a percentage, or out of range, parse as byte size */
 
                 r = parse_size(rvalue, 1024, &k);
-                if (r < 0 || k <= 0 || (uint64_t) (size_t) k != k) {
-                        log_syntax(unit, LOG_ERR, filename, line, r, "Failed to parse size value, ignoring: %s", rvalue);
+                if (r >= 0 && (k <= 0 || (uint64_t) (size_t) k != k))
+                        r = -ERANGE;
+                if (r < 0) {
+                        log_syntax(unit, LOG_ERR, filename, line, r, "Failed to parse size value '%s', ignoring: %m", rvalue);
                         return 0;
                 }
 
