@@ -1,5 +1,4 @@
 #!/usr/bin/env python3
-#  -*- Mode: python; coding: utf-8; indent-tabs-mode: nil -*- */
 # SPDX-License-Identifier: LGPL-2.1+
 
 import sys
@@ -47,12 +46,22 @@ TEMPLATE = '''\
         <refsect1>
                 <title>Environment variables</title>
 
-                <para>Environment variables understood by the elogind
-                manager and other programs.</para>
+                <para>Environment variables understood by the elogind manager
+                and other programs and environment variable-compatible settings.</para>
 
                 <variablelist id='environment-variables' />
         </refsect1>
 
+        <refsect1>
+                <title>EFI variables</title>
+
+                <para>EFI variables understood by
+                <citerefentry><refentrytitle>elogind-boot</refentrytitle><manvolnum>7</manvolnum></citerefentry>
+                and other programs.</para>
+
+                <variablelist id='efi-variables' />
+        </refsect1>
+
         <refsect1>
                 <title>UDEV directives</title>
 
@@ -99,16 +108,25 @@ TEMPLATE = '''\
         </refsect1>
 
         <refsect1>
-                <title>System manager directives</title>
+                <title><citerefentry><refentrytitle>elogind.nspawn</refentrytitle><manvolnum>5</manvolnum></citerefentry>
+                directives</title>
 
-                <para>Directives for configuring the behaviour of the
-                elogind process.</para>
+                <para>Directives for configuring elogind-nspawn containers.</para>
 
-                <variablelist id='elogind-directives' />
+                <variablelist id='nspawn-directives' />
         </refsect1>
 
         <refsect1>
-                <title>command line options</title>
+                <title>Program configuration options</title>
+
+                <para>Directives for configuring the behaviour of the
+                elogind process and other tools through configuration files.</para>
+
+                <variablelist id='config-directives' />
+        </refsect1>
+
+        <refsect1>
+                <title>Command line options</title>
 
                 <para>Command-line options accepted by programs in the
                 elogind suite.</para>
